==> plasma-framework-5.74.0.zip: plasma-framework-5.74.0/po/lt/scripts/libplasma5/plasmoids.js <==
// First argument must be the same as in .po file, usually capitalized. 2nd and 3rd lowercase unless it is a name.
addDictCases("2D grafikai", "2D grafikų", "šiuos 2D grafikus");
addDictCases("Adapteriai", "adapterių", "šiuos adapterius");
addDictCases("Akys", "akių", "šias akis");
addDictCases("Aktyvaus lango valdymas", "aktyvaus lango valdymo", "šį aktyvaus lango valdymą");
addDictCases("Akumuliatorius ir ryškumas", "akumuliatoriaus ir ryškumo", "šį akumuliatorių ir ryškumą");
addDictCases("Analoginis laikrodis", "analoginio laikrodžio", "šį analoginį laikrodį");
addDictCases("Aplankų rodinys", "aplankų rodinio", "šį aplankų rodinį");
addDictCases("Asmuo", "asmens", "šį asmenį");
addDictCases("Atminties būsena", "atminties būsenos", "šią atminties būseną");
addDictCases("Atnaujinimai", "atnaujinimų", "šiuos atnaujinimus");
addDictCases("Automatinis paleidimas", "automatinio paleidimo", "šį automatinį paleidimą");
addDictCases("Baterija ir ryškumas", "baterijos ir ryškumo", "šiuos bateriją ir ryškumą");
addDictCases("CPU apkrovos stebėtojas", "CPU apkrovos stebėtojo","šį CPU apkrovos stebėtoją");
addDictCases("Darbalaukio aplankas", "darbalaukio aplanko", "šį darbalaukio aplanką");
addDictCases("Darbalaukio fono papildiniai", "darbalaukio fono papildinių", "šiuos darbalaukio fono papildinius");
addDictCases("Darbalaukis", "darbalaukio", "šį darbalaukį");
addDictCases("Data ir laikas", "datos ir laiko", "šią datą ir laiką");
addDictCases("Didelės piktogramos", "didelių piktogramų", "šias dideles piktogramas");
addDictCases("Dienos paveikslas", "dienos paveikslo", "šį dienos paveikslą");
addDictCases("Dvejetainis laikrodis", "dvejetainio laikrodžio", "šį dvejetainį laikrodį");
addDictCases("Ekrano konfigūracija", "ekrano konfigūracijos", "šią ekrano konfigūraciją");
addDictCases("Failų paieška", "failų paieškos", "šią failų paiešką");
addDictCases("Failų tvarkytuvė", "failų tvarkytuvės", "šią failų tvarkytuvę");
addDictCases("Garsas", "garso", "šį garsą");
addDictCases("Garsumas", "garsumo", "šį garsumą");
addDictCases("Greitas pokalbis", "greito pokalbio", "šį greitą pokalbį");
addDictCases("Informatyvus", "informatyvaus", "šį informatyvų");
addDictCases("Įrenginiai", "įrenginių", "šiuos įrenginius");
addDictCases("Iškarpinė", "iškarpinės", "šią iškarpinę");
addDictCases("Įvesties metodų skydelis", "įvesties metodų skydelio", "šį įvesties metodų skydelį");
addDictCases("Jaustukų parinkiklis", "jaustukų parinkiklio", "šį jaustukų parinkiklį");
addDictCases("Jutiklinis kilimėlis", "jutiklinio kilimėlio", "šį jutiklinį kilimėlį");
addDictCases("Kalendorius", "kalendoriaus", "šį kalendorių");
addDictCases("Kate seansai", "Kate seansų", "šiuos Kate seansus");
addDictCases("KDE dokumentacija", "KDE dokumentacijos", "šią KDE dokumentaciją");
addDictCases("KDE prieinamumo įrankis", "KDE prieinamumo įrankio", "šį KDE prieinamumo įrankį");
addDictCases("KDevelop sesijos", "KDevelop sesijų", "šias KDevelop sesijas");
addDictCases("Klaviatūros indikatorius", "klaviatūros indikatoriaus", "šį klaviatūros indikatorių");
addDictCases("Komiksai", "komiksų", "šiuos komiksus");
addDictCases("Komiksų piešinių serija", "komiksų piešinių serijos", "šią komiksų piešinių seriją");
addDictCases("Komiksų piešinių serijos", "komiksų piešinių serijų", "šias komiksų piešinių serijas");
addDictCases("Kompaktiškas", "kompaktiško", "šį kompaktišką");
addDictCases("Konsole profiliai", "Konsole profilių", "šiuos Konsole profilius");
addDictCases("Laikmatis", "laikmačio", "šį laikmatį");
addDictCases("Langų sąrašas", "langų sąrašo", "šį langų sąrašą");
addDictCases("Latte užduotys", "Latte užduočių", "šias Latte užduotis");
addDictCases("Leidžiamas disko duomenų kiekis", "leidžiamo disko duomenų kiekio", "šį leidžiamą disko duomenų kiekį");
addDictCases("Mažos piktogramos", "mažų piktogramų", "šias mažas piktogramas");
addDictCases("Medijos leistuvė", "medijos leistuvės", "šią medijos leistuvę");
addDictCases("Medijos rėmelis", "medijos rėmelio", "šį medijos rėmelį");
addDictCases("Miniatiūros", "miniatiūrų", "šias miniatiūras");
addDictCases("Miniatiūrų tinklelis", "miniatiūrų tinklelio", "šį miniatiūrų tinklelį");
addDictCases("Naktinės spalvos valdymas", "naktinės spalvos valdymo", "šį naktinės spalvos valdymą");
addDictCases("Naudotojų perjungiklis", "naudotojų perjungiklio", "šį naudotojų perjungiklį");
addDictCases("Netikslus laikrodis", "netikslaus laikrodžio", "šį netikslų laikrodį");
addDictCases("Numatytosios programos", "numatytųjų programų", "šias numatytąsias programas");
addDictCases("Orų pranešimai", "orų pranešimų", "šiuos orų pranešimus");
addDictCases("Orų prognozė", "orų prognozės", "šią orų prognozę");
addDictCases("Paieška", "paieškos", "šią paiešką");
addDictCases("Paprastas meniu", "paprasto meniu", "šį paprastą meniu");
addDictCases("Penkiolika dalių", "penkiolika dalių", "šias penkiolika dalių");
addDictCases("Peržiūros", "peržiūrų", "šias peržiūras");
addDictCases("Piktograma", "piktogramos", "šią piktogramą");
addDictCases("Plasma įskiepių grupavimas", "Plasma įskiepių grupavimo", "šį Plasma įskiepių grupavimą");
addDictCases("Plasma valdikliai", "Plasma valdiklių", "šiuos Plasma valdiklius");
addDictCases("Pranešimai apie įrenginius", "pranešimų apie įrenginius", "šiuos pranešimus apie įrenginius");
addDictCases("Pranešimai", "pranešimų", "šiuos pranešimus");
addDictCases("Prieinamumas", "prieinamumo", "šį prieinamumą");
addDictCases("Procesoriaus apkrovos prižiūryklė", "procesoriaus apkrovos prižiūryklės", "šią procesoriaus apkrovos prižiūryklę");
addDictCases("Programos meniu tarnyba", "programos meniu tarnybos", "šią programos meniu tarnybą");
addDictCases("Programų meniu", "programų meniu", "šį programų meniu");
addDictCases("Programų paleidyklė", "programų paleidyklės", "šią programų paleidyklę");
addDictCases("Programų skydelis", "programų skydelio", "šį programų skydelį");
addDictCases("Puslapių perjungiklis", "puslapių perjungiklio", "šį puslapių perjungiklį");
addDictCases("Rašybos tikrinimas", "rašybos tikrinimo", "šį rašybos tikrinimą");
addDictCases("Rašybos tikrinimo paleidiklis", "rašybos tikrinimo paleidiklio", "šį rašybos tikrinimo paleidiklį");
addDictCases("Redshift valdymas", "Redshift valdymo", "šį Redshift valdymą");
addDictCases("Rodyti darbalaukį", "rodyti darbalaukį", "šį rodyti darbalaukį");
addDictCases("Saityno naršyklė", "saityno naršyklės", "šią saityno naršyklę");
addDictCases("Sistemos apkrovos žiūryklė", "sistemos apkrovos žiūryklės", "šią sistemos apkrovos žiūryklę");
addDictCases("Sistemos dėklas", "sistemos dėklo", "šį sistemos dėklą");
addDictCases("Skaičiuoklis", "skaičiuoklio", "šį skaičiuoklį");
addDictCases("Skaitmeninis laikrodis", "skaitmeninio laikrodžio", "šį skaitmeninį laikrodį");
addDictCases("Skydelio skirtukas", "skydelio skirtuko", "šį skydelio skirtuką");
addDictCases("Skydelis", "skydelio", "šį skydelį");
addDictCases("Slėptuvės", "slėptuvių", "šias slėptuves");
addDictCases("Spalvos", "spalvų", "šias spalvas");
addDictCases("Spalvų parinkiklis", "spalvų parinkiklio", "šį spalvų parinkiklį");
addDictCases("Spalvų rinkiniai", "spalvų rinkinių", "šiuos spalvų rinkinius");
addDictCases("Spartusis bendrinimas", "sparčiojo bendrinimo", "šį spartųjį bendrinimą");
addDictCases("Spartusis paleidimas", "sparčiojo paleidimo", "šį spartųjį paleidimą");
addDictCases("Spausdintuvai", "spausdintuvų", "šiuos spausdintuvus");
addDictCases("specialūs simboliai", "specialių simbolių", "šiuos specialius simbolius");
addDictCases("Specialūs simboliai", "specialių simbolių", "šiuos specialius simbolius");
addDictCases("Standartinis meniu", "standartinio meniu", "šį standartinį meniu");
addDictCases("Standžiojo disko I/O prižiūryklė", "standžiojo disko I/O prižiūryklės", "šią standžiojo disko I/O prižiūryklę");
addDictCases("Standžiojo disko vietos panaudojimas", "standžiojo disko vietos panaudojimo", "šį standžiojo disko vietos panaudojimą");
addDictCases("Suskleisti visus langus", "visų langų suskleidimo", "šį visų langų suskleidimą");
addDictCases("Šiukšlinė", "šiukšlinės", "šią šiukšlinę");
addDictCases("Techn. žinynas", "techn. žinyno", "šį techn. žinyną");
addDictCases("Tik piktogramų užduočių tvarkytuvė", "tik piktogramų užduočių tvarkytuvės", "šią tik piktogramų užduočių tvarkytuvę");
addDictCases("Tik tekstas", "tik teksto", "šį tik tekstą");
addDictCases("Tinklai", "tinklų", "šiuos tinklus");
addDictCases("Tinklelis", "tinklelio", "šį tinklelį");
addDictCases("Tinklo prižiūryklė", "tinklo prižiūryklės", "šią tinklo prižiūryklę");
addDictCases("Tuščias skydelis", "tuščio skydelio", "šį tuščią skydelį");
addDictCases("Užduočių tvarkytuvė", "užduočių tvarkytuvės", "šią užduočių tvarkytuvę");
addDictCases("Užrakinti/atsijungti", "užrakinti/atsijungti", "šį užrakinti/atsijungti");
addDictCases("Užrašai", "užrašų", "šiuos užrašus");
addDictCases("Veiklos", "veiklų", "šias veiklas");
addDictCases("Veiklų juosta", "veiklų juostos", "šią veiklų juostą");
addDictCases("Veiklų perjungiklis", "veiklų perjungiklio", "šį veiklų perjungiklį");
addDictCases("Veiklų tvarkytuvė", "veiklų tvarkytuvės", "šią veiklų tvarkytuvę");
addDictCases("Vienetų keitiklis", "vienetų keitiklio", "šį vienetų keitiklį");
addDictCases("Viki kelionės", "Viki kelionių", "šias Viki keliones");
addDictCases("Vikipedija", "Vikipedijos", "šią Vikipediją");
addDictCases("Visuotinis meniu", "visuotinio meniu", "šį visuotinį meniu");
addDictCases("Žodynas", "žodyno", "šį žodyną");

==> plasma-framework-5.109.0.zip: plasma-framework-5.109.0/po/lt/scripts/libplasma5/plasmoids.js <==
// First argument must be the same as in .po file, usually capitalized. 2nd and 3rd lowercase unless it is a name.
addDictCases("2D grafikai", "2D grafikų", "šiuos 2D grafikus");
addDictCases("Adapteriai", "adapterių", "šiuos adapterius");
addDictCases("Akys", "akių", "šias akis");
addDictCases("Aktyvaus lango valdymas", "aktyvaus lango valdymo", "šį aktyvaus lango valdymą");
addDictCases("Akumuliatorius ir ryškumas", "akumuliatoriaus ir ryškumo", "šį akumuliatorių ir ryškumą");
addDictCases("Analoginis laikrodis", "analoginio laikrodžio", "šį analoginį laikrodį");
addDictCases("Aplankų rodinys", "aplankų rodinio", "šį aplankų rodinį");
addDictCases("Asmuo", "asmens", "šį asmenį");
addDictCases("Atminties būsena", "atminties būsenos", "šią atminties būseną");
addDictCases("Atnaujinimai", "atnaujinimų", "šiuos atnaujinimus");
addDictCases("Automatinis paleidimas", "automatinio paleidimo", "šį automatinį paleidimą");
addDictCases("Baterija ir ryškumas", "baterijos ir ryškumo", "šiuos bateriją ir ryškumą");
addDictCases("CPU apkrovos stebėtojas", "CPU apkrovos stebėtojo","šį CPU apkrovos stebėtoją");
addDictCases("Darbalaukio aplankas", "darbalaukio aplanko", "šį darbalaukio aplanką");
addDictCases("Darbalaukio fono papildiniai", "darbalaukio fono papildinių", "šiuos darbalaukio fono papildinius");
addDictCases("Darbalaukis", "darbalaukio", "šį darbalaukį");
addDictCases("Data ir laikas", "datos ir laiko", "šią datą ir laiką");
addDictCases("Didelės piktogramos", "didelių piktogramų", "šias dideles piktogramas");
addDictCases("Dienos paveikslas", "dienos paveikslo", "šį dienos paveikslą");
addDictCases("Dvejetainis laikrodis", "dvejetainio laikrodžio", "šį dvejetainį laikrodį");
addDictCases("Ekrano konfigūracija", "ekrano konfigūracijos", "šią ekrano konfigūraciją");
addDictCases("Failų paieška", "failų paieškos", "šią failų paiešką");
addDictCases("Failų tvarkytuvė", "failų tvarkytuvės", "šią failų tvarkytuvę");
addDictCases("Garsas", "garso", "šį garsą");
addDictCases("Garsumas", "garsumo", "šį garsumą");
addDictCases("Greitas pokalbis", "greito pokalbio", "šį greitą pokalbį");
addDictCases("Informatyvus", "informatyvaus", "šį informatyvų");
addDictCases("Įrenginiai", "įrenginių", "šiuos įrenginius");
addDictCases("Iškarpinė", "iškarpinės", "šią iškarpinę");
addDictCases("Įvesties metodų skydelis", "įvesties metodų skydelio", "šį įvesties metodų skydelį");
addDictCases("Jaustukų parinkiklis", "jaustukų parinkiklio", "šį jaustukų parinkiklį");
addDictCases("Jutiklinis kilimėlis", "jutiklinio kilimėlio", "šį jutiklinį kilimėlį");
addDictCases("Kalendorius", "kalendoriaus", "šį kalendorių");
addDictCases("Kate seansai", "Kate seansų", "šiuos Kate seansus");
addDictCases("KDE dokumentacija", "KDE dokumentacijos", "šią KDE dokumentaciją");
addDictCases("KDE prieinamumo įrankis", "KDE prieinamumo įrankio", "šį KDE prieinamumo įrankį");
addDictCases("KDevelop sesijos", "KDevelop sesijų", "šias KDevelop sesijas");
addDictCases("Klaviatūros indikatorius", "klaviatūros indikatoriaus", "šį klaviatūros indikatorių");
addDictCases("Komiksai", "komiksų", "šiuos komiksus");
addDictCases("Komiksų piešinių serija", "komiksų piešinių serijos", "šią komiksų piešinių seriją");
addDictCases("Komiksų piešinių serijos", "komiksų piešinių serijų", "šias komiksų piešinių serijas");
addDictCases("Kompaktiškas", "kompaktiško", "šį kompaktišką");
addDictCases("Konsole profiliai", "Konsole profilių", "šiuos Konsole profilius");
addDictCases("Laikmatis", "laikmačio", "šį laikmatį");
addDictCases("Langų sąrašas", "langų sąrašo", "šį langų sąrašą");
addDictCases("Latte užduotys", "Latte užduočių", "šias Latte užduotis");
addDictCases("Leidžiamas disko duomenų kiekis", "leidžiamo disko duomenų kiekio", "šį leidžiamą disko duomenų kiekį");
addDictCases("Mažos piktogramos", "mažų piktogramų", "šias mažas piktogramas");
addDictCases("Medijos leistuvė", "medijos leistuvės", "šią medijos leistuvę");
addDictCases("Medijos rėmelis", "medijos rėmelio", "šį medijos rėmelį");
addDictCases("Miniatiūros", "miniatiūrų", "šias miniatiūras");
addDictCases("Miniatiūrų tinklelis", "miniatiūrų tinklelio", "šį miniatiūrų tinklelį");
addDictCases("Naktinės spalvos valdymas", "naktinės spalvos valdymo", "šį naktinės spalvos valdymą");
addDictCases("Naudotojų perjungiklis", "naudotojų perjungiklio", "šį naudotojų perjungiklį");
addDictCases("Netikslus laikrodis", "netikslaus laikrodžio", "šį netikslų laikrodį");
addDictCases("Numatytosios programos", "numatytųjų programų", "šias numatytąsias programas");
addDictCases("Orų pranešimai", "orų pranešimų", "šiuos orų pranešimus");
addDictCases("Orų prognozė", "orų prognozės", "šią orų prognozę");
addDictCases("Paieška", "paieškos", "šią paiešką");
addDictCases("Paprastas meniu", "paprasto meniu", "šį paprastą meniu");
addDictCases("Penkiolika dalių", "penkiolika dalių", "šias penkiolika dalių");
addDictCases("Peržiūros", "peržiūrų", "šias peržiūras");
addDictCases("Piktograma", "piktogramos", "šią piktogramą");
addDictCases("Plasma įskiepių grupavimas", "Plasma įskiepių grupavimo", "šį Plasma įskiepių grupavimą");
addDictCases("Plasma valdikliai", "Plasma valdiklių", "šiuos Plasma valdiklius");
addDictCases("Pranešimai apie įrenginius", "pranešimų apie įrenginius", "šiuos pranešimus apie įrenginius");
addDictCases("Pranešimai", "pranešimų", "šiuos pranešimus");
addDictCases("Prieinamumas", "prieinamumo", "šį prieinamumą");
addDictCases("Procesoriaus apkrovos prižiūryklė", "procesoriaus apkrovos prižiūryklės", "šią procesoriaus apkrovos prižiūryklę");
addDictCases("Programos meniu tarnyba", "programos meniu tarnybos", "šią programos meniu tarnybą");
addDictCases("Programų meniu", "programų meniu", "šį programų meniu");
addDictCases("Programų paleidyklė", "programų paleidyklės", "šią programų paleidyklę");
addDictCases("Programų skydelis", "programų skydelio", "šį programų skydelį");
addDictCases("Puslapių perjungiklis", "puslapių perjungiklio", "šį puslapių perjungiklį");
addDictCases("Rašybos tikrinimas", "rašybos tikrinimo", "šį rašybos tikrinimą");
addDictCases("Rašybos tikrinimo paleidiklis", "rašybos tikrinimo paleidiklio", "šį rašybos tikrinimo paleidiklį");
addDictCases("Redshift valdymas", "Redshift valdymo", "šį Redshift valdymą");
addDictCases("Rodyti darbalaukį", "rodyti darbalaukį", "šį rodyti darbalaukį");
addDictCases("Saityno naršyklė", "saityno naršyklės", "šią saityno naršyklę");
addDictCases("Sistemos apkrovos žiūryklė", "sistemos apkrovos žiūryklės", "šią sistemos apkrovos žiūryklę");
addDictCases("Sistemos dėklas", "sistemos dėklo", "šį sistemos dėklą");
addDictCases("Skaičiuoklis", "skaičiuoklio", "šį skaičiuoklį");
addDictCases("Skaitmeninis laikrodis", "skaitmeninio laikrodžio", "šį skaitmeninį laikrodį");
addDictCases("Skydelio skirtukas", "skydelio skirtuko", "šį skydelio skirtuką");
addDictCases("Skydelis", "skydelio", "šį skydelį");
addDictCases("Slėptuvės", "slėptuvių", "šias slėptuves");
addDictCases("Spalvos", "spalvų", "šias spalvas");
addDictCases("Spalvų parinkiklis", "spalvų parinkiklio", "šį spalvų parinkiklį");
addDictCases("Spalvų rinkiniai", "spalvų rinkinių", "šiuos spalvų rinkinius");
addDictCases("Spartusis bendrinimas", "sparčiojo bendrinimo", "šį spartųjį bendrinimą");
addDictCases("Spartusis paleidimas", "sparčiojo paleidimo", "šį spartųjį paleidimą");
addDictCases("Spausdintuvai", "spausdintuvų", "šiuos spausdintuvus");
addDictCases("specialūs simboliai", "specialių simbolių", "šiuos specialius simbolius");
addDictCases("Specialūs simboliai", "specialių simbolių", "šiuos specialius simbolius");
addDictCases("Standartinis meniu", "standartinio meniu", "šį standartinį meniu");
addDictCases("Standžiojo disko I/O prižiūryklė", "standžiojo disko I/O prižiūryklės", "šią standžiojo disko I/O prižiūryklę");
addDictCases("Standžiojo disko vietos panaudojimas", "standžiojo disko vietos panaudojimo", "šį standžiojo disko vietos panaudojimą");
addDictCases("Suskleisti visus langus", "visų langų suskleidimo", "šį visų langų suskleidimą");
addDictCases("Šiukšlinė", "šiukšlinės", "šią šiukšlinę");
addDictCases("Techn. žinynas", "techn. žinyno", "šį techn. žinyną");
addDictCases("Tik piktogramų užduočių tvarkytuvė", "tik piktogramų užduočių tvarkytuvės", "šią tik piktogramų užduočių tvarkytuvę");
addDictCases("Tik tekstas", "tik teksto", "šį tik tekstą");
addDictCases("Tinklai", "tinklų", "šiuos tinklus");
addDictCases("Tinklelis", "tinklelio", "šį tinklelį");
addDictCases("Tinklo prižiūryklė", "tinklo prižiūryklės", "šią tinklo prižiūryklę");
addDictCases("Tuščias skydelis", "tuščio skydelio", "šį tuščią skydelį");
addDictCases("Užduočių tvarkytuvė", "užduočių tvarkytuvės", "šią užduočių tvarkytuvę");
addDictCases("Užrakinti/atsijungti", "užrakinti/atsijungti", "šį užrakinti/atsijungti");
addDictCases("Užrašai", "užrašų", "šiuos užrašus");
addDictCases("Veiklos", "veiklų", "šias veiklas");
addDictCases("Veiklų juosta", "veiklų juostos", "šią veiklų juostą");
addDictCases("Veiklų perjungiklis", "veiklų perjungiklio", "šį veiklų perjungiklį");
addDictCases("Veiklų tvarkytuvė", "veiklų tvarkytuvės", "šią veiklų tvarkytuvę");
addDictCases("Vienetų keitiklis", "vienetų keitiklio", "šį vienetų keitiklį");
addDictCases("Viki kelionės", "Viki kelionių", "šias Viki keliones");
addDictCases("Vikipedija", "Vikipedijos", "šią Vikipediją");
addDictCases("Visuotinis meniu", "visuotinio meniu", "šį visuotinį meniu");
addDictCases("Žodynas", "žodyno", "šį žodyną");
addDictCases("Užrakto klavišų būsena", "užrakto klavišų būsenos", "šią užrakto klavišų būseną");
addDictCases("Piešimo planšetė", "piešimo planšetės", "šią piešimo planšetę");
addDictCases("Žvilgsnis į darbalaukį", "žvilgsnio į darbalaukį", "šį žvilgsnį į darbalaukį");
